=======
History
=======

1.1.0 (2024-XX-XX)
------------------

* "Rogue" release
* Python 3.9 support dropped (due to issues with scipy)
* Python 3.13 support added
* Added feature: wave decomposition into incoming and reflected waves (cores.core_wave_decomposition.decompose_linear_ZS_series)
* Added feature: calculate wave steepness and high or low-frequency wave parameters (Spectrum class)

1.0.0 (2023-10-27)
------------------

* Initial "Swell" release